@@ -297,6 +297,17 @@ class Builder:
                 source == target['target']):
                 self.__scons_env.Alias(target['name'], install_node)
 
+    def __setup_scons_post_actions(self, target):
+        """Set scons up to execute post build actions
+        
+        Args:
+            target: target dict with all options."""
+
+        post_actions = target.get('post_actions',[])
+
+        for action in post_actions:
+            self.__scons_env.AddPostAction(target['name'], action)
+
     def __setup_scons_build(self, target):
         """Set scons up to build either exec or staticlib
         
@@ -316,10 +327,11 @@ class Builder:
 
         if not build_node is None:
 
-            # NOTE: alias build name to target so we can do things line:
+            # NOTE: alias build name to target so we can do things like:
             # scons my_pretty_target_name
             self.__scons_env.Alias(target['name'], build_node)
 
+
     def __setup_scons_lint(self, target):
         """Set scons up to lint source
 
@@ -351,6 +363,7 @@ class Builder:
         self.__install_files(target)
         self.__setup_scons_lint(target)
         self.__setup_scons_build(target)
+        self.__setup_scons_post_actions(target)
         self.__setup_scons_variant_dir(target)
 
 def get_build_option_value(option_name):
